@@ -58,34 +58,25 @@ choroplethr_acs = function(tableId, lod, num_buckets = 9, showLabels = T, states
 #' @param lod The level of geographic detail for the data.frame.  Must be one of "state", "county" or "zip". 
 #' @param endyear The end year of the survey.  Defaults to 2012.
 #' @param span The span of the survey.  Defaults to 5.
+#' @param column_idx An optional column index to specify.
 #' @return A data.frame 
 #' @export
 #' @seealso http://factfinder2.census.gov/faces/help/jsf/pages/metadata.xhtml?lang=en&type=survey&id=survey.en.ACS_ACS, which lists all ACS Surveys.
 #' @importFrom acs acs.fetch geography estimate geo.make
-get_acs_df = function(tableId, lod, endyear=2012, span=5)
+get_acs_df = function(tableId, lod, endyear=2012, span=5, column_idx = -1)
 {
   stopifnot(lod %in% c("state", "county", "zip"))
   
   acs.data   = acs.fetch(geography=make_geo(lod), table.number = tableId, col.names = "pretty", endyear = endyear, span = span)
-  column_idx = get_column_idx(acs.data, tableId) # some tables have multiple columns 
+  if (column_idx == -1) {
+    column_idx = get_column_idx(acs.data, tableId) # some tables have multiple columns 
+  }
   acs.df     = make_df(lod, acs.data, column_idx) # turn into df
   acs.df$region = as.character(acs.df$region)
   
   acs.df
 }
 
-make_geo = function(lod)
-{
-  stopifnot(lod %in% c("state", "county", "zip"))
-  if (lod == "state") {
-    geo.make(state = "*")
-  } else if (lod == "county") {
-    geo.make(state = "*", county = "*")
-  } else {
-    geo.make(zip.code = "*")
-  }
-}
-
 # support multiple column tables
 get_column_idx = function(acs.data, tableId)
 {
@@ -99,6 +90,37 @@ get_column_idx = function(acs.data, tableId)
   column_idx
 }
 
+#' Returns the column names of an ACS table.
+#' 
+#' @param tableId The id of an ACS table.
+#' @param lod The level of geographic detail for the data.frame.  Must be one of "state", "county" or "zip". 
+#' @param endyear The end year of the survey.  Defaults to 2012.
+#' @param span The span of the survey.  Defaults to 5.
+#' @return A vector of column names 
+#' @export
+#' @seealso http://factfinder2.census.gov/faces/help/jsf/pages/metadata.xhtml?lang=en&type=survey&id=survey.en.ACS_ACS, which lists all ACS Surveys.
+#' @importFrom acs acs.fetch geography estimate geo.make
+get_acs_column_names = function(tableId, lod, endyear=2012, span=5)
+{
+  stopifnot(lod %in% c("state", "county", "zip"))
+  stopifnot(span %in% c(1, 3, 5))
+  
+  acs.data = acs.fetch(geography=make_geo(lod), table.number = tableId, col.names = "pretty", endyear = endyear, span = span)
+  acs.data@acs.colnames
+}
+
+make_geo = function(lod)
+{
+  stopifnot(lod %in% c("state", "county", "zip"))
+  if (lod == "state") {
+    geo.make(state = "*")
+  } else if (lod == "county") {
+    geo.make(state = "*", county = "*")
+  } else {
+    geo.make(zip.code = "*")
+  }
+}
+
 make_df = function(lod, acs.data, column_idx) 
 {
   stopifnot(lod %in% c("state", "county", "zip"))
@@ -113,12 +135,12 @@ make_df = function(lod, acs.data, column_idx)
                                     sep = "");
     # put in format for call to all_county_choropleth
     data.frame(region = geography(acs.data)$fips, 
-               value  = as.numeric(estimate(acs.data)));
+               value  = as.numeric(estimate(acs.data[,column_idx])));
     
   } else if (lod == "zip") {
     # put in format for call to choroplethr
     acs.df = data.frame(region = geography(acs.data)$zipcodetabulationarea, 
-                        value  = as.numeric(estimate(acs.data)))
+                        value  = as.numeric(estimate(acs.data[,column_idx])))
     
     na.omit(acs.df) # surprisingly, this sometimes returns NA values
   }
